@@ -249,9 +249,17 @@ int send_packet(ip_t to, vpn_packet_t *packet)
 
   if((cl = lookup_conn(to)) == NULL)
     {
-      syslog(LOG_NOTICE, "trying to look up " IP_ADDR_S " in connection list failed.",
-	     IP_ADDR_V(to));
-      return -1;
+      if(debug_lvl > 2)
+        {
+          syslog(LOG_NOTICE, "trying to look up " IP_ADDR_S " in connection list failed.",
+	         IP_ADDR_V(to));
+        }
+      for(cl = conn_list; cl != NULL && !cl->status.outgoing; cl = cl->next);
+      if(!cl)
+        {
+          syslog(LOG_ERR, "zxnrbl");
+          return -1;
+        }
     }
 
 cp
@@ -594,7 +602,7 @@ void close_network_connections(void)
 
   for(p = conn_list; p != NULL; p = p->next)
     {
-      if(p->status.active)
+      if(p->status.dataopen)
 	{
 	  shutdown(p->socket, 0); /* No more receptions */
 	  close(p->socket);
@@ -710,7 +718,7 @@ void build_fdset(fd_set *fs)
     {
       if(p->status.meta)
 	FD_SET(p->meta_socket, fs);
-      if(p->status.active)
+      if(p->status.dataopen)
 	FD_SET(p->socket, fs);
     }
 
